bindiff-rs 0.1.1

Rust bindings to BinDiff
docs.rs failed to build bindiff-rs-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: bindiff-rs-0.1.8

Usage

use bindiff::BinDiff;

fn main() -> anyhow::Result<()> {
    let input_path = std::env::args().nth(1)
        .ok_or_else(|| anyhow::anyhow!("Please provide a path to a BinDiff file"))?;
    let bd = BinDiff::open(&input_path)?;

    // Read function matches
    let func_matches = bd.read_function_matches()?;
    for func_match in func_matches {
        println!("{:#?}", func_match);
    }

    Ok(())
}

License

MIT Copyright (c) 2025 blacktop