IndexRange

Struct IndexRange 

pub struct IndexRange {
    pub begin_index: Option<i32>,
    pub end_index: Option<i32>,
}
This is a space optimization. The instructions for an individual basic block will usually be in a continuous index range. Thus it is more efficient to store the range instead of individual indices. However, this does not hold true for all basic blocks, so we need to be able to store multiple index ranges per block.

Fields

begin_index: Option<i32>

These work like begin and end iterators, i.e. the sequence is [begin_index, end_index). If the sequence only contains a single element end_index will be omitted.

end_index: Option<i32>

Implementations

Source

impl IndexRange

pub fn begin_index(&self) -> i32

Returns the value of begin_index, or the default value if begin_index is unset.

pub fn end_index(&self) -> i32

Returns the value of end_index, or the default value if end_index is unset.