pub struct IndexRange {
pub begin_index: Option<i32>,
pub end_index: Option<i32>,
}Expand description
This is a space optimization. The instructions for an individual basic block will usually be in a continuous index range. Thus it is more efficient to store the range instead of individual indices. However, this does not hold true for all basic blocks, so we need to be able to store multiple index ranges per block.
Fields
begin_index: Option<i32>These work like begin and end iterators, i.e. the sequence is [begin_index, end_index). If the sequence only contains a single element end_index will be omitted.
end_index: Option<i32>Implementations
Sourceimpl IndexRange
impl IndexRange